@@ -138,10 +138,17 @@ typedef struct {
 #define _WRITE_CDR    2
 #define _WRITE_CDRW   4
 #define _WRITE_DUMMY  8
+#define _READ_DVD     16
+#define _WRITE_DVD    32
 #define DRIVE_READER(drive) (drive && (drive->type & _READ_CDR))
 #define DRIVE_WRITER(drive) (drive && (drive->type & _WRITE_CDR))
+#define DRIVE_DVDREADER(drive) (drive && (drive->type & _READ_DVD))
+#define DRIVE_DVDWRITER(drive) (drive && (drive->type & _WRITE_DVD))
+
 #define DRIVE_CDRW_WRITER(drive) (drive && (drive->type & _WRITE_CDRW))
-#define DRIVE_ICONE(drive) (drive->type & _WRITE_CDR) ? GCDRWpetiteIcone : GCDpetiteIcone
+#define DRIVE_ICONE(drive)  (drive->type & _WRITE_DVD ? GDVDRWpetiteIcone : \
+                            (drive->type & _WRITE_CDR ? GCDRWpetiteIcone : \
+                            (drive->type & _READ_DVD ? GDVDpetiteIcone : GCDpetiteIcone)))
 
 typedef struct {
   gchar *name;  /* label du lecteur */
@@ -179,7 +186,7 @@ extern gchar *make_audio_fileslist(gint Anbrfiles);
 /* data.c */
 extern gboolean preparedata(GHashTable *Ahash, GError **Aerror);
 
-/* interface.c */
+/* images.c */
 extern GdkPixbuf *GDirIcone;
 extern GdkPixbuf *GFileIcone;
 extern GdkPixbuf *GFileImage;
@@ -192,6 +199,13 @@ extern GdkPixbuf *GAudioIcone;
 extern GdkPixbuf *GCDRWIcone;
 extern GdkPixbuf *GCDpetiteIcone;
 extern GdkPixbuf *GCDRWpetiteIcone;
+extern GdkPixbuf *GDVDpetiteIcone;
+extern GdkPixbuf *GDVDRWpetiteIcone;
+
+extern void load_all_images();
+extern void free_all_images();
+
+/* interface.c */
 extern GSList *Gmedialist;
 extern Tmediaentry Gdefaultmedia[];
 extern void remplirecombovitesse(GtkComboBox *Acombo, gchar *Alecident);
@@ -253,6 +267,8 @@ extern void remplirecombograveur(GtkComboBox *Acombo, gint Aquoi);
 extern void remplirelistegraveur(GtkTreeView *Aliste);
 extern gboolean read_config(GError **Aerror);
 extern void restore_main_window_pos(GtkWidget *Awindow1);
+extern void use_last_dir(GtkFileChooser *Awidget);
+extern void save_last_dir(GtkFileChooser *Awidget);
 
 /* matos.c */
 extern GSList *Glistdrives;
@@ -301,7 +317,7 @@ extern gchar *format_length(guint32 Alennbr);
 extern gchar *format_size(guint32 Asize);
 extern gboolean sc_str_has_casesuffix(gchar *Astr, gchar *Asuffix);
 extern gpointer sc_hash_table_lookupv(GHashTable *Ahash, gchar *Akeyformat, ...);
-extern gchar *sc_get_filename(gchar *Afilename);
+extern gchar * sc_strescape (const gchar *source);
 extern void sc_line_data_copy(GtkTreeModel *Amodel, GtkTreeIter *Aiterde, GtkTreeIter *Aitervers);
 extern gboolean sc_str_match(gchar *Lpattern, gchar *Lstr);
 
