@@ -47,7 +47,7 @@ gboolean readcd_makeimage_callback(GIOChannel *Astd, GIOCondition Acond, gpointe
   GtkLabel *Ltitle = GTK_LABEL(g_hash_table_lookup(Lhash, "gravetitle"));
   GtkProgressBar *Lprogressbar = GTK_PROGRESS_BAR(g_hash_table_lookup(Lhash, "pb_total"));
   GtkProgressBar *Lprogressbar2 = GTK_PROGRESS_BAR(g_hash_table_lookup(Lhash, "pb_step"));
-  gboolean *Lcont = (gboolean *) g_hash_table_lookup(Lhash, "cont"); /* on traite encore des donnees ? */
+  gint *Lcont = (gint *) g_hash_table_lookup(Lhash, "cont"); /* on traite encore des donnees ? */
   GError **Lerreur = (GError **) g_hash_table_lookup(Lhash, "gerror"); /* pointeur erreur */
   gdouble *Lreadtodo = (gdouble *) g_hash_table_lookup(Lhash, "readtodo"); /* nombre de secteur a traiter */
   gint *Ltodo = (gint *) g_hash_table_lookup(Lhash, "todo"); /* nombre de piste a traiter */
@@ -62,7 +62,7 @@ gboolean readcd_makeimage_callback(GIOChannel *Astd, GIOCondition Acond, gpointe
 
   /* fin du callback lorsque l'on recoi un signal comme quoi le pipe est ferme */
   if (Acond == G_IO_HUP || Acond == G_IO_ERR) {
-    *Lcont = FALSE;
+    *Lcont = 0;
     return FALSE;
   }
  
@@ -94,7 +94,7 @@ _DEB("=>%s", Lbuffer);
     if (*Lreadtodo == 0) {
       g_set_error(Lerreur, GRAVEMAN_ERROR, _ERR_UNKNOWN_ERROR, 
             _("Communication error with readcd while trying to read cd size."));
-      *Lcont = FALSE;
+      *Lcont = 0;
       return FALSE;
     }
     if (*Lvitesse && **Lvitesse) {
@@ -144,7 +144,7 @@ gint make_image(GHashTable *Ahash, GError **Aerror)
   gchar *Lcommandline;
   GIOChannel *Lcom, *Lcomerr;
   guint Lcomevent, Lcomerrevent;
-  gboolean Lcont = TRUE;
+  gint *Lcont = g_hash_table_lookup(Ahash, "cont");
   GtkLabel *Ltitle = GTK_LABEL(g_hash_table_lookup(Ahash, "gravetitle"));
   gint *Lpid = (gint *) g_hash_table_lookup(Ahash, "pid");
   GtkWidget *Lvitesse = g_hash_table_lookup(Ahash, "dstcopyspeed");
@@ -180,8 +180,7 @@ gint make_image(GHashTable *Ahash, GError **Aerror)
     g_warning("ERROR EXECUTION !\n");
     return FALSE;
   }
-  Lcont = TRUE;
-  g_hash_table_insert(Ahash, "cont", &Lcont);
+  *Lcont = 1;
   g_hash_table_insert(Ahash, "readtodo", &Lreadtodo);
 
   Lcom = g_io_channel_unix_new( g_out );
@@ -195,7 +194,7 @@ gint make_image(GHashTable *Ahash, GError **Aerror)
   g_io_channel_set_flags( Lcomerr, G_IO_FLAG_NONBLOCK, NULL );
   Lcomerrevent = g_io_add_watch (Lcomerr, (G_IO_IN | G_IO_HUP | G_IO_ERR | G_IO_PRI),
                                       readcd_makeimage_callback, Ahash); 
-  while (Lcont) {
+  while (*Lcont>0) {
    gtk_main_iteration();    
   }
   g_source_remove(Lcomevent);
@@ -210,7 +209,6 @@ gint make_image(GHashTable *Ahash, GError **Aerror)
   *Lpid = 0;
 
   g_hash_table_remove(Ahash, "readtodo");
-  g_hash_table_remove(Ahash, "cont");
 
   if (*Aerror) {
     _DEB("IL Y A UNE ERREUR !!");
@@ -229,14 +227,14 @@ gboolean readcd_redirect_callback(GIOChannel *Astd, GIOCondition Acond, gpointer
 {
   GtkWidget *Lwindow1 = (GtkWidget *) Adata;
   gchar Lbuffer[_BUF_SIZE];
-  gboolean *Lcont = (gboolean *) g_object_get_data(G_OBJECT(Lwindow1), "contsrc"); /* on traite encore des donnees ? */
+  gint *Lcont = (gint *) g_object_get_data(G_OBJECT(Lwindow1), "contsrc"); /* on traite encore des donnees ? */
   GError **Lerreur = (GError **) g_object_get_data(G_OBJECT(Lwindow1), "gerror"); /* pointeur erreur */
   GIOChannel *Lcdrecord = (GIOChannel *) g_object_get_data(G_OBJECT(Lwindow1), "cdrecord");
   gsize Llu = 0, Lecris = 0;
 
   /* fin du callback lorsque l'on recoi un signal comme quoi le pipe est ferme */
   if (Acond == G_IO_HUP || Acond == G_IO_ERR) {
-    *Lcont = FALSE;
+    *Lcont = 0;
     return FALSE;
   }
   g_io_channel_read_chars(Astd, Lbuffer, _BUF_SIZE-1, &Llu, Lerreur);  
@@ -258,14 +256,14 @@ gboolean readcd_getsize_callback(GIOChannel *Astd, GIOCondition Acond, gpointer
 {
   GIOStatus Lstatus;
   GHashTable *Lhash = (GHashTable *)Adata;
-  gboolean *Lcont = (gboolean *) g_hash_table_lookup(Lhash, "cont"); /* on traite encore des donnees ? */
+  gint *Lcont = (gint *) g_hash_table_lookup(Lhash, "cont"); /* on traite encore des donnees ? */
   gint *Ltodo = (gint *) g_hash_table_lookup(Lhash, "todo"); /* nombre de piste a traiter */
   gchar *f, *e;
   gchar *Lbuffer = NULL;  
 
   /* fin du callback lorsque l'on recoi un signal comme quoi le pipe est ferme */
   if (Acond == G_IO_HUP || Acond == G_IO_ERR) {
-    *Lcont = FALSE;
+    *Lcont = 0;
     return FALSE;
   }
   
@@ -277,7 +275,7 @@ gboolean readcd_getsize_callback(GIOChannel *Astd, GIOCondition Acond, gpointer
       *e=0;
       *Ltodo = atoi(f);
     }
-    *Lcont = FALSE;
+    *Lcont = 0;
     return FALSE;
   }
   g_free(Lbuffer);
